@@ -1,3 +1,52 @@
+/*
+ *
+ *    OPEN-XCHANGE legal information
+ *
+ *    All intellectual property rights in the Software are protected by
+ *    international copyright laws.
+ *
+ *
+ *    In some countries OX, OX Open-Xchange, open xchange and OXtender
+ *    as well as the corresponding Logos OX Open-Xchange and OX are registered
+ *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    The use of the Logos is not covered by the GNU General Public License.
+ *    Instead, you are allowed to use these Logos according to the terms and
+ *    conditions of the Creative Commons License, Version 2.5, Attribution,
+ *    Non-commercial, ShareAlike, and the interpretation of the term
+ *    Non-commercial applicable to the aforementioned license is published
+ *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ *
+ *    Please make sure that third-party modules and libraries are used
+ *    according to their respective licenses.
+ *
+ *    Any modifications to this package must retain all copyright notices
+ *    of the original copyright holder(s) for the original code used.
+ *
+ *    After any such modifications, the original and derivative code shall remain
+ *    under the copyright of the copyright holder(s) and/or original author(s)per
+ *    the Attribution and Assignment Agreement that can be located at
+ *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
+ *    given Attribution for the derivative code and a license granting use.
+ *
+ *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Mail: info@open-xchange.com
+ *
+ *
+ *     This program is free software; you can redistribute it and/or modify it
+ *     under the terms of the GNU General Public License, Version 2 as published
+ *     by the Free Software Foundation.
+ *
+ *     This program is distributed in the hope that it will be useful, but
+ *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ *     for more details.
+ *
+ *     You should have received a copy of the GNU General Public License along
+ *     with this program; if not, write to the Free Software Foundation, Inc., 59
+ *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *
+ */
+
 package com.openexchange.contacts.ldap.property;
 
 import java.util.Properties;
@@ -5,9 +54,17 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.contacts.ldap.exceptions.LdapConfigurationException;
 import com.openexchange.contacts.ldap.exceptions.LdapConfigurationException.Code;
 
+/**
+ * Holds all folder specific properties
+ *
+ * @author <a href="mailto:dennis.sieben@open-xchange.com">Dennis Sieben</a>
+ *
+ */
 public class FolderProperties {
 
     
+    private static final int DEFAULT_REFRESH_INTERVAL = 10000;
+
     public interface SetterFallbackClosure {
         public void set(String property);
         
@@ -91,7 +148,8 @@ public class FolderProperties {
         baseDN_distributionlist("baseDN_distributionlist"),
         outlook_support("outlook_support"),
         ADS_deletion_support("ADS_deletion_support"),
-        referrals("referrals");
+        referrals("referrals"),
+        refreshinterval("refreshinterval");
         
         private final String name;
         
@@ -164,6 +222,10 @@ public class FolderProperties {
     
     private ReferralTypes referrals;
     
+    private int refreshinterval;
+    
+    
+    
     public static FolderProperties getFolderPropertiesFromProperties(final ConfigurationService configuration, final String name, final String folder, final String contextnr, final StringBuilder logBuilder) throws LdapConfigurationException {
         final String prefix = PropertyHandler.bundlename + "context" + contextnr + "." + folder + ".";
         
@@ -370,6 +432,19 @@ public class FolderProperties {
                 return ReferralTypes.valueOf(string);
             }
         });
+        
+        final String refreshintervalstring = checkStringProperty(parameterObject, Parameters.refreshinterval);
+        try {
+            if (null != refreshintervalstring) {
+                retval.setRefreshinterval(Integer.parseInt(refreshintervalstring));
+            } else {
+                retval.setRefreshinterval(DEFAULT_REFRESH_INTERVAL);
+            }
+            logBuilder.append("\trefreshinterval: ").append(retval.getRefreshinterval()).append('\n');
+        } catch (final NumberFormatException e) {
+            throw new LdapConfigurationException(Code.INVALID_REFRESHINTERVAL, refreshintervalstring);
+        }
+
 
         final String memoryMappingString = checkStringProperty(parameterObject, Parameters.memorymapping);
         
@@ -444,6 +519,12 @@ public class FolderProperties {
         return referrals;
     }
 
+    public int getRefreshinterval() {
+        return refreshinterval;
+    }
+
+
+
     public int getPagesize() {
         return pagesize;
     }
@@ -597,6 +678,12 @@ public class FolderProperties {
         this.referrals = referrals;
     }
 
+    private void setRefreshinterval(int refreshinterval) {
+        this.refreshinterval = refreshinterval;
+    }
+
+
+
     private void setSearchfilter(final String searchfilter) {
         this.searchfilter = searchfilter;
     }
